#!/bin/sh
#
# Copyright 2004-2010 Bob Friesenhahn <bfriesen@simple.dallas.tx.us>
#
# This file is part of Magick++, the C++ API for GraphicsMagick and
# ImageMagick.  Please see the file "COPYING" included with Magick++
# for usage and copying restrictions.
#

SRCDIR=`dirname $0`
SRCDIR=`cd $SRCDIR; pwd`/
export SRCDIR
cd Magick++/demo || exit 1

executable=`echo $0 | sed -e 's:.*/::g;s:test_::;s:\.sh::'`

${MEMCHECK} ./analyze "$SRCDIR/model.miff"
status=$?
exit $status


